@@ -48,6 +48,7 @@ enum rdns_request_type {
 	RDNS_REQUEST_INVALID = -1,
 	RDNS_REQUEST_A = 1,
 	RDNS_REQUEST_NS = 2,
+	RDNS_REQUEST_CNAME = 5,
 	RDNS_REQUEST_SOA = 6,
 	RDNS_REQUEST_PTR = 12,
 	RDNS_REQUEST_MX = 15,
@@ -101,6 +102,9 @@ union rdns_reply_element_un {
 		uint16_t datalen;
 		uint8_t *data;
 	} tlsa;
+	struct {
+		char *name;
+	} cname;
 };
 
 struct rdns_reply_entry {
