@@ -1,5 +1,5 @@
 --[[
-Copyright (c) 2018, Vsevolod Stakhov <vsevolod@highsecure.ru>
+Copyright (c) 2022, Vsevolod Stakhov <vsevolod@rspamd.com>
 Copyright (c) 2019, Carsten Rosenberg <c.rosenberg@heinlein-support.de>
 
 Licensed under the Apache License, Version 2.0 (the "License");
@@ -42,7 +42,9 @@ local function log_clean(task, rule, msg)
 end
 
 local function match_patterns(default_sym, found, patterns, dyn_weight)
-  if type(patterns) ~= 'table' then return default_sym, dyn_weight end
+  if type(patterns) ~= 'table' then
+    return default_sym, dyn_weight
+  end
   if not patterns[1] then
     for sym, pat in pairs(patterns) do
       if pat:match(found) then
@@ -62,20 +64,29 @@ local function match_patterns(default_sym, found, patterns, dyn_weight)
   end
 end
 
-local function yield_result(task, rule, vname, dyn_weight, is_fail)
+local function yield_result(task, rule, vname, dyn_weight, is_fail, maybe_part)
   local all_whitelisted = true
   local patterns
   local symbol
-  local threat_table = {}
+  local threat_table
   local threat_info
   local flags
 
+  if type(vname) == 'string' then
+    threat_table = { vname }
+  elseif type(vname) == 'table' then
+    threat_table = vname
+  end
+
+
   -- This should be more generic
   if not is_fail then
     patterns = rule.patterns
     symbol = rule.symbol
     threat_info = rule.detection_category .. 'found'
-    if not dyn_weight then dyn_weight = 1.0 end
+    if not dyn_weight then
+      dyn_weight = 1.0
+    end
   elseif is_fail == 'fail' then
     patterns = rule.patterns_fail
     symbol = rule.symbol_fail
@@ -93,12 +104,6 @@ local function yield_result(task, rule, vname, dyn_weight, is_fail)
     dyn_weight = 1.0
   end
 
-  if type(vname) == 'string' then
-    table.insert(threat_table, vname)
-  elseif type(vname) == 'table' then
-    threat_table = vname
-  end
-
   for _, tm in ipairs(threat_table) do
     local symname, symscore = match_patterns(symbol, tm, patterns, dyn_weight)
     if rule.whitelist and rule.whitelist:get_key(tm) then
@@ -107,7 +112,15 @@ local function yield_result(task, rule, vname, dyn_weight, is_fail)
       all_whitelisted = false
       rspamd_logger.infox(task, '%s: result - %s: "%s - score: %s"',
           rule.log_prefix, threat_info, tm, symscore)
-      task:insert_result(symname, symscore, tm)
+
+      if maybe_part and rule.show_attachments and maybe_part:get_filename() then
+        local fname = maybe_part:get_filename()
+        task:insert_result(symname, symscore, string.format("%s|%s",
+            tm, fname))
+      else
+        task:insert_result(symname, symscore, tm)
+      end
+
     end
   end
 
@@ -126,7 +139,9 @@ end
 
 local function message_not_too_large(task, content, rule)
   local max_size = tonumber(rule.max_size)
-  if not max_size then return true end
+  if not max_size then
+    return true
+  end
   if #content > max_size then
     rspamd_logger.infox(task, "skip %s check as it is too large: %s (%s is allowed)",
         rule.log_prefix, #content, max_size)
@@ -137,7 +152,9 @@ end
 
 local function message_not_too_small(task, content, rule)
   local min_size = tonumber(rule.min_size)
-  if not min_size then return true end
+  if not min_size then
+    return true
+  end
   if #content < min_size then
     rspamd_logger.infox(task, "skip %s check as it is too small: %s (%s is allowed)",
         rule.log_prefix, #content, min_size)
@@ -147,21 +164,24 @@ local function message_not_too_small(task, content, rule)
 end
 
 local function message_min_words(task, rule)
-  if rule.text_part_min_words then
-    local text_parts_empty = false
+  if rule.text_part_min_words and tonumber(rule.text_part_min_words) > 0 then
+    local text_part_above_limit = false
     local text_parts = task:get_text_parts()
 
     local filter_func = function(p)
-      return p:get_words_count() <= tonumber(rule.text_part_min_words)
+      return p:get_words_count() >= tonumber(rule.text_part_min_words)
     end
 
     fun.each(function(p)
-      text_parts_empty = true
-      rspamd_logger.infox(task, '%s: #words is less then text_part_min_words: %s',
-        rule.log_prefix, rule.text_part_min_words)
+      text_part_above_limit = true
     end, fun.filter(filter_func, text_parts))
 
-    return text_parts_empty
+    if not text_part_above_limit then
+      rspamd_logger.infox(task, '%s: #words in all text parts is below text_part_min_words limit: %s',
+          rule.log_prefix, rule.text_part_min_words)
+    end
+
+    return text_part_above_limit
   else
     return true
   end
@@ -170,8 +190,8 @@ end
 local function dynamic_scan(task, rule)
   if rule.dynamic_scan then
     if rule.action ~= 'reject' then
-      local metric_result = task:get_metric_score('default')
-      local metric_action = task:get_metric_action('default')
+      local metric_result = task:get_metric_score()
+      local metric_action = task:get_metric_action()
       local has_pre_result = task:has_pre_result()
       -- ToDo: needed?
       -- Sometimes leads to FPs
@@ -179,7 +199,7 @@ local function dynamic_scan(task, rule)
       --  rspamd_logger.infox(task, '%s: aborting: %s', rule.log_prefix, "result is already reject")
       --  return false
       --elseif metric_result[1] > metric_result[2]*2 then
-      if metric_result[1] > metric_result[2]*2 then
+      if metric_result[1] > metric_result[2] * 2 then
         rspamd_logger.infox(task, '%s: aborting: %s', rule.log_prefix, 'score > 2 * reject_level: ' .. metric_result[1])
         return false
       elseif has_pre_result and metric_action == 'reject' then
@@ -196,7 +216,7 @@ local function dynamic_scan(task, rule)
   end
 end
 
-local function need_check(task, content, rule, digest, fn)
+local function need_check(task, content, rule, digest, fn, maybe_part)
 
   local uncached = true
   local key = digest
@@ -207,20 +227,23 @@ local function need_check(task, content, rule, digest, fn)
       data = lua_util.str_split(data, '\t')
       local threat_string = lua_util.str_split(data[1], '\v')
       local score = data[2] or rule.default_score
+
       if threat_string[1] ~= 'OK' then
         if threat_string[1] == 'MACRO' then
-          yield_result(task, rule, 'File contains macros', 0.0, 'macro')
+          yield_result(task, rule, 'File contains macros',
+              0.0, 'macro', maybe_part)
         elseif threat_string[1] == 'ENCRYPTED' then
-          yield_result(task, rule, 'File is encrypted', 0.0, 'encrypted')
+          yield_result(task, rule, 'File is encrypted',
+              0.0, 'encrypted', maybe_part)
         else
           lua_util.debugm(rule.name, task, '%s: got cached threat result for %s: %s - score: %s',
               rule.log_prefix, key, threat_string[1], score)
-          yield_result(task, rule, threat_string, score)
+          yield_result(task, rule, threat_string, score, false, maybe_part)
         end
 
       else
         lua_util.debugm(rule.name, task, '%s: got cached negative result for %s: %s',
-          rule.log_prefix, key, threat_string[1])
+            rule.log_prefix, key, threat_string[1])
       end
       uncached = false
     else
@@ -235,10 +258,10 @@ local function need_check(task, content, rule, digest, fn)
     local f_dynamic_scan = dynamic_scan(task, rule)
 
     if uncached and
-      f_message_not_too_large and
-      f_message_not_too_small and
-      f_message_min_words and
-      f_dynamic_scan then
+        f_message_not_too_large and
+        f_message_not_too_small and
+        f_message_min_words and
+        f_dynamic_scan then
 
       fn()
 
@@ -256,7 +279,7 @@ local function need_check(task, content, rule, digest, fn)
         false, -- is write
         redis_av_cb, --callback
         'GET', -- command
-        {key} -- arguments)
+        { key } -- arguments)
     ) then
       return true
     end
@@ -266,9 +289,11 @@ local function need_check(task, content, rule, digest, fn)
 
 end
 
-local function save_cache(task, digest, rule, to_save, dyn_weight)
+local function save_cache(task, digest, rule, to_save, dyn_weight, maybe_part)
   local key = digest
-  if not dyn_weight then dyn_weight = 1.0 end
+  if not dyn_weight then
+    dyn_weight = 1.0
+  end
 
   local function redis_set_cb(err)
     -- Do nothing
@@ -277,7 +302,7 @@ local function save_cache(task, digest, rule, to_save, dyn_weight)
           rule.detection_category, to_save, key, err)
     else
       lua_util.debugm(rule.name, task, '%s: saved cached result for %s: %s - score %s - ttl %s',
-        rule.log_prefix, key, to_save, dyn_weight, rule.cache_expire)
+          rule.log_prefix, key, to_save, dyn_weight, rule.cache_expire)
     end
   end
 
@@ -285,7 +310,12 @@ local function save_cache(task, digest, rule, to_save, dyn_weight)
     to_save = table.concat(to_save, '\v')
   end
 
-  local value = table.concat({to_save, dyn_weight}, '\t')
+  local value_tbl = { to_save, dyn_weight }
+  if maybe_part and rule.show_attachments and maybe_part:get_filename() then
+    local fname = maybe_part:get_filename()
+    table.insert(value_tbl, fname)
+  end
+  local value = table.concat(value_tbl, '\t')
 
   if rule.redis_params and rule.prefix then
     key = rule.prefix .. key
@@ -360,31 +390,31 @@ local function gen_extension(fname)
 
   local ext = {}
   for n = 1, 2 do
-      ext[n] = #filename_parts > n and string.lower(filename_parts[#filename_parts + 1 - n]) or nil
+    ext[n] = #filename_parts > n and string.lower(filename_parts[#filename_parts + 1 - n]) or nil
   end
-  return ext[1],ext[2],filename_parts
+  return ext[1], ext[2], filename_parts
 end
 
 local function check_parts_match(task, rule)
 
   local filter_func = function(p)
-    local mtype,msubtype = p:get_type()
+    local mtype, msubtype = p:get_type()
     local detected_ext = p:get_detected_ext()
     local fname = p:get_filename()
     local ext, ext2
 
     if rule.scan_all_mime_parts == false then
-    -- check file extension and filename regex matching
+      -- check file extension and filename regex matching
       --lua_util.debugm(rule.name, task, '%s: filename: |%s|%s|', rule.log_prefix, fname)
       if fname ~= nil then
-        ext,ext2 = gen_extension(fname)
+        ext, ext2 = gen_extension(fname)
         --lua_util.debugm(rule.name, task, '%s: extension, fname: |%s|%s|%s|', rule.log_prefix, ext, ext2, fname)
         if match_filter(task, rule, ext, rule.mime_parts_filter_ext, 'ext')
             or match_filter(task, rule, ext2, rule.mime_parts_filter_ext, 'ext') then
           lua_util.debugm(rule.name, task, '%s: extension matched: |%s|%s|', rule.log_prefix, ext, ext2)
           return true
         elseif match_filter(task, rule, fname, rule.mime_parts_filter_regex, 'regex') then
-          lua_util.debugm(rule.name, task, '%s: filname regex matched', rule.log_prefix)
+          lua_util.debugm(rule.name, task, '%s: filename regex matched', rule.log_prefix)
           return true
         end
       end
@@ -412,8 +442,8 @@ local function check_parts_match(task, rule)
       if p:is_archive() then
         local arch = p:get_archive()
         local filelist = arch:get_files_full(1000)
-        for _,f in ipairs(filelist) do
-          ext,ext2 = gen_extension(f.name)
+        for _, f in ipairs(filelist) do
+          ext, ext2 = gen_extension(f.name)
           if match_filter(task, rule, ext, rule.mime_parts_filter_ext, 'ext')
               or match_filter(task, rule, ext2, rule.mime_parts_filter_ext, 'ext') then
             lua_util.debugm(rule.name, task, '%s: extension matched in archive: |%s|%s|', rule.log_prefix, ext, ext2)
@@ -438,14 +468,15 @@ local function check_parts_match(task, rule)
     end
 
     if rule.scan_all_mime_parts ~= false then
+      local is_part_checkable = (p:is_attachment() and (not p:is_image() or rule.scan_image_mime))
       if detected_ext then
         -- We know what to scan!
         local magic = lua_magic_types[detected_ext] or {}
 
-        if p:is_attachment() or magic.av_check ~= false then
+        if magic.av_check ~= false or is_part_checkable then
           return true
         end
-      elseif p:is_attachment() then
+      elseif is_part_checkable then
         -- Just rely on attachment property
         return true
       end
@@ -460,13 +491,13 @@ end
 local function check_metric_results(task, rule)
 
   if rule.action ~= 'reject' then
-    local metric_result = task:get_metric_score('default')
-    local metric_action = task:get_metric_action('default')
+    local metric_result = task:get_metric_score()
+    local metric_action = task:get_metric_action()
     local has_pre_result = task:has_pre_result()
 
     if rule.symbol_type == 'postfilter' and metric_action == 'reject' then
       return true, 'result is already reject'
-    elseif metric_result[1] > metric_result[2]*2 then
+    elseif metric_result[1] > metric_result[2] * 2 then
       return true, 'score > 2 * reject_level: ' .. metric_result[1]
     elseif has_pre_result and metric_action == 'reject' then
       return true, 'pre_result reject is set'
