@@ -52,16 +52,30 @@ rspamd_scan_result_dtor(gpointer d)
 			kh_destroy(rspamd_options_hash, sres->options);
 		}
 	});
+
 	kh_destroy(rspamd_symbols_hash, r->symbols);
 	kh_destroy(rspamd_symbols_group_hash, r->sym_groups);
 }
 
+static void
+rspamd_metric_actions_foreach_cb(int i, struct rspamd_action *act, void *cbd)
+{
+	struct rspamd_scan_result *metric_res = (struct rspamd_scan_result *) cbd;
+	metric_res->actions_config[i].flags = RSPAMD_ACTION_RESULT_DEFAULT;
+	if (!(act->flags & RSPAMD_ACTION_NO_THRESHOLD)) {
+		metric_res->actions_config[i].cur_limit = act->threshold;
+	}
+	else {
+		metric_res->actions_config[i].flags |= RSPAMD_ACTION_RESULT_NO_THRESHOLD;
+	}
+	metric_res->actions_config[i].action = act;
+}
+
 struct rspamd_scan_result *
 rspamd_create_metric_result(struct rspamd_task *task,
 							const gchar *name, gint lua_sym_cbref)
 {
 	struct rspamd_scan_result *metric_res;
-	guint i;
 
 	metric_res = rspamd_mempool_alloc0(task->task_pool,
 									   sizeof(struct rspamd_scan_result));
@@ -89,27 +103,11 @@ rspamd_create_metric_result(struct rspamd_task *task,
 	}
 
 	if (task->cfg) {
-		struct rspamd_action *act, *tmp;
-
+		size_t nact = rspamd_config_actions_size(task->cfg);
 		metric_res->actions_config = rspamd_mempool_alloc0(task->task_pool,
-														   sizeof(struct rspamd_action_config) * HASH_COUNT(task->cfg->actions));
-		i = 0;
-
-		HASH_ITER(hh, task->cfg->actions, act, tmp)
-		{
-			metric_res->actions_config[i].flags = RSPAMD_ACTION_RESULT_DEFAULT;
-			if (!(act->flags & RSPAMD_ACTION_NO_THRESHOLD)) {
-				metric_res->actions_config[i].cur_limit = act->threshold;
-			}
-			else {
-				metric_res->actions_config[i].flags |= RSPAMD_ACTION_RESULT_NO_THRESHOLD;
-			}
-			metric_res->actions_config[i].action = act;
-
-			i++;
-		}
-
-		metric_res->nactions = i;
+														   sizeof(struct rspamd_action_config) * nact);
+		rspamd_config_actions_foreach_enumerate(task->cfg, rspamd_metric_actions_foreach_cb, metric_res);
+		metric_res->nactions = nact;
 	}
 
 	rspamd_mempool_add_destructor(task->task_pool,
@@ -1093,10 +1091,7 @@ rspamd_find_metric_result(struct rspamd_task *task,
 {
 	struct rspamd_scan_result *res;
 
-	if (name == NULL) {
-		return task->result;
-	}
-	else if (strcmp(name, "default") == 0) {
+	if (name == NULL || strcmp(name, "default") == 0) {
 		return task->result;
 	}
 
