@@ -23,14 +23,15 @@
 #include "ref.h"
 
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 extern "C" {
 #endif
 
 struct rspamd_http_connection;
 
 enum rspamd_http_message_type {
-	HTTP_REQUEST = 0, HTTP_RESPONSE
+	HTTP_REQUEST = 0,
+	HTTP_RESPONSE
 };
 
 /**
@@ -38,51 +39,51 @@ enum rspamd_http_message_type {
  * @param conn
  * @return
  */
-struct rspamd_http_message *rspamd_http_connection_steal_msg (
-		struct rspamd_http_connection *conn);
+struct rspamd_http_message *rspamd_http_connection_steal_msg(
+	struct rspamd_http_connection *conn);
 
 /**
  * Copy the current message from a connection to deal with separately
  * @param conn
  * @return
  */
-struct rspamd_http_message *rspamd_http_connection_copy_msg (
-		struct rspamd_http_message *msg, GError **err);
+struct rspamd_http_message *rspamd_http_connection_copy_msg(
+	struct rspamd_http_message *msg, GError **err);
 
 /**
  * Create new HTTP message
  * @param type request or response
  * @return new http message
  */
-struct rspamd_http_message *rspamd_http_new_message (enum rspamd_http_message_type type);
+struct rspamd_http_message *rspamd_http_new_message(enum rspamd_http_message_type type);
 
 /**
  * Increase refcount number for an HTTP message
  * @param msg message to use
  * @return
  */
-struct rspamd_http_message *rspamd_http_message_ref (struct rspamd_http_message *msg);
+struct rspamd_http_message *rspamd_http_message_ref(struct rspamd_http_message *msg);
 
 /**
  * Decrease number of refcounts for http message
  * @param msg
  */
-void rspamd_http_message_unref (struct rspamd_http_message *msg);
+void rspamd_http_message_unref(struct rspamd_http_message *msg);
 
 /**
  * Sets a key for peer
  * @param msg
  * @param pk
  */
-void rspamd_http_message_set_peer_key (struct rspamd_http_message *msg,
-									   struct rspamd_cryptobox_pubkey *pk);
+void rspamd_http_message_set_peer_key(struct rspamd_http_message *msg,
+									  struct rspamd_cryptobox_pubkey *pk);
 
 /**
  * Create HTTP message from URL
  * @param url
  * @return new message or NULL
  */
-struct rspamd_http_message *rspamd_http_message_from_url (const gchar *url);
+struct rspamd_http_message *rspamd_http_message_from_url(const gchar *url);
 
 /**
  * Returns body for a message
@@ -90,8 +91,8 @@ struct rspamd_http_message *rspamd_http_message_from_url (const gchar *url);
  * @param blen pointer where to save body length
  * @return pointer to body start
  */
-const gchar *rspamd_http_message_get_body (struct rspamd_http_message *msg,
-										   gsize *blen);
+const gchar *rspamd_http_message_get_body(struct rspamd_http_message *msg,
+										  gsize *blen);
 
 /**
  * Set message's body from the string
@@ -100,16 +101,16 @@ const gchar *rspamd_http_message_get_body (struct rspamd_http_message *msg,
  * @param len
  * @return TRUE if a message's body has been set
  */
-gboolean rspamd_http_message_set_body (struct rspamd_http_message *msg,
-									   const gchar *data, gsize len);
+gboolean rspamd_http_message_set_body(struct rspamd_http_message *msg,
+									  const gchar *data, gsize len);
 
 /**
  * Set message's method by name
  * @param msg
  * @param method
  */
-void rspamd_http_message_set_method (struct rspamd_http_message *msg,
-									 const gchar *method);
+void rspamd_http_message_set_method(struct rspamd_http_message *msg,
+									const gchar *method);
 
 /**
  * Maps fd as message's body
@@ -117,8 +118,8 @@ void rspamd_http_message_set_method (struct rspamd_http_message *msg,
  * @param fd
  * @return TRUE if a message's body has been set
  */
-gboolean rspamd_http_message_set_body_from_fd (struct rspamd_http_message *msg,
-											   gint fd);
+gboolean rspamd_http_message_set_body_from_fd(struct rspamd_http_message *msg,
+											  gint fd);
 
 /**
  * Uses rspamd_fstring_t as message's body, string is consumed by this operation
@@ -126,8 +127,8 @@ gboolean rspamd_http_message_set_body_from_fd (struct rspamd_http_message *msg,
  * @param fstr
  * @return TRUE if a message's body has been set
  */
-gboolean rspamd_http_message_set_body_from_fstring_steal (struct rspamd_http_message *msg,
-														  rspamd_fstring_t *fstr);
+gboolean rspamd_http_message_set_body_from_fstring_steal(struct rspamd_http_message *msg,
+														 rspamd_fstring_t *fstr);
 
 /**
  * Uses rspamd_fstring_t as message's body, string is copied by this operation
@@ -135,8 +136,8 @@ gboolean rspamd_http_message_set_body_from_fstring_steal (struct rspamd_http_mes
  * @param fstr
  * @return TRUE if a message's body has been set
  */
-gboolean rspamd_http_message_set_body_from_fstring_copy (struct rspamd_http_message *msg,
-														 const rspamd_fstring_t *fstr);
+gboolean rspamd_http_message_set_body_from_fstring_copy(struct rspamd_http_message *msg,
+														const rspamd_fstring_t *fstr);
 
 /**
  * Appends data to message's body
@@ -145,8 +146,8 @@ gboolean rspamd_http_message_set_body_from_fstring_copy (struct rspamd_http_mess
  * @param len
  * @return TRUE if a message's body has been set
  */
-gboolean rspamd_http_message_append_body (struct rspamd_http_message *msg,
-										  const gchar *data, gsize len);
+gboolean rspamd_http_message_append_body(struct rspamd_http_message *msg,
+										 const gchar *data, gsize len);
 
 /**
  * Append a header to http message
@@ -154,27 +155,27 @@ gboolean rspamd_http_message_append_body (struct rspamd_http_message *msg,
  * @param name
  * @param value
  */
-void rspamd_http_message_add_header (struct rspamd_http_message *msg,
-									 const gchar *name,
-									 const gchar *value);
+void rspamd_http_message_add_header(struct rspamd_http_message *msg,
+									const gchar *name,
+									const gchar *value);
 
-void rspamd_http_message_add_header_len (struct rspamd_http_message *msg,
+void rspamd_http_message_add_header_len(struct rspamd_http_message *msg,
+										const gchar *name,
+										const gchar *value,
+										gsize len);
+
+void rspamd_http_message_add_header_fstr(struct rspamd_http_message *msg,
 										 const gchar *name,
-										 const gchar *value,
-										 gsize len);
-
-void rspamd_http_message_add_header_fstr (struct rspamd_http_message *msg,
-										  const gchar *name,
-										  rspamd_fstring_t *value);
+										 rspamd_fstring_t *value);
 
 /**
  * Search for a specified header in message
  * @param msg message
  * @param name name of header
  */
-const rspamd_ftok_t *rspamd_http_message_find_header (
-		struct rspamd_http_message *msg,
-		const gchar *name);
+const rspamd_ftok_t *rspamd_http_message_find_header(
+	struct rspamd_http_message *msg,
+	const gchar *name);
 
 /**
  * Search for a header that has multiple values
@@ -182,9 +183,9 @@ const rspamd_ftok_t *rspamd_http_message_find_header (
  * @param name
  * @return list of rspamd_ftok_t * with values
  */
-GPtrArray *rspamd_http_message_find_header_multiple (
-		struct rspamd_http_message *msg,
-		const gchar *name);
+GPtrArray *rspamd_http_message_find_header_multiple(
+	struct rspamd_http_message *msg,
+	const gchar *name);
 
 /**
  * Remove specific header from a message
@@ -192,14 +193,14 @@ GPtrArray *rspamd_http_message_find_header_multiple (
  * @param name
  * @return
  */
-gboolean rspamd_http_message_remove_header (struct rspamd_http_message *msg,
-											const gchar *name);
+gboolean rspamd_http_message_remove_header(struct rspamd_http_message *msg,
+										   const gchar *name);
 
 /**
  * Free HTTP message
  * @param msg
  */
-void rspamd_http_message_free (struct rspamd_http_message *msg);
+void rspamd_http_message_free(struct rspamd_http_message *msg);
 
 /**
  * Extract arguments from a message's URI contained inside query string decoding
@@ -208,26 +209,26 @@ void rspamd_http_message_free (struct rspamd_http_message *msg);
  * @return new GHashTable which maps rspamd_ftok_t* to rspamd_ftok_t*
  * (table must be freed by a caller)
  */
-GHashTable *rspamd_http_message_parse_query (struct rspamd_http_message *msg);
+GHashTable *rspamd_http_message_parse_query(struct rspamd_http_message *msg);
 
 /**
  * Increase refcount for shared file (if any) to prevent early memory unlinking
  * @param msg
  */
-struct rspamd_storage_shmem *rspamd_http_message_shmem_ref (struct rspamd_http_message *msg);
+struct rspamd_storage_shmem *rspamd_http_message_shmem_ref(struct rspamd_http_message *msg);
 
 /**
  * Decrease external ref for shmem segment associated with a message
  * @param msg
  */
-void rspamd_http_message_shmem_unref (struct rspamd_storage_shmem *p);
+void rspamd_http_message_shmem_unref(struct rspamd_storage_shmem *p);
 
 /**
  * Returns message's flags
  * @param msg
  * @return
  */
-guint rspamd_http_message_get_flags (struct rspamd_http_message *msg);
+guint rspamd_http_message_get_flags(struct rspamd_http_message *msg);
 
 /**
  * Returns an HTTP hostname for a message, derived from a header if it has it
@@ -236,10 +237,17 @@ guint rspamd_http_message_get_flags (struct rspamd_http_message *msg);
  * @param hostlen output of the host length
  * @return
  */
-const gchar* rspamd_http_message_get_http_host (struct rspamd_http_message *msg,
-		gsize *hostlen);
+const gchar *rspamd_http_message_get_http_host(struct rspamd_http_message *msg,
+											   gsize *hostlen);
 
-#ifdef  __cplusplus
+/**
+ * Returns true if a message has standard port (80 or 443 for https)
+ * @param msg
+ * @return
+ */
+bool rspamd_http_message_is_standard_port(struct rspamd_http_message *msg);
+
+#ifdef __cplusplus
 }
 #endif
 
