@@ -1,11 +1,11 @@
-/*-
- * Copyright 2018 Vsevolod Stakhov
+/*
+ * Copyright 2023 Vsevolod Stakhov
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -411,6 +411,9 @@ rspamd_parse_kv_list(
 		/* Examine the state */
 		switch (data->state) {
 		case map_read_key:
+		case map_read_key_slashed:
+		case map_read_key_quoted:
+		case map_read_key_after_slash:
 			if (p - c > 0) {
 				/* Store a single key */
 				MAP_STORE_KEY;
@@ -525,6 +528,13 @@ void rspamd_map_helper_insert_radix_resolve(gpointer st, gconstpointer key, gcon
 	struct rspamd_map *map;
 
 	map = r->map;
+
+	if (!key) {
+		msg_warn_map("cannot insert NULL value in the map: %s",
+					 map->name);
+		return;
+	}
+
 	tok.begin = key;
 	tok.len = strlen(key);
 
