@@ -1,11 +1,11 @@
-/*-
- * Copyright 2022 Vsevolod Stakhov
+/*
+ * Copyright 2023 Vsevolod Stakhov
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -63,7 +63,7 @@ gint rspamd_symcache_add_symbol(struct rspamd_symcache *cache,
 								gint priority,
 								symbol_func_t func,
 								gpointer user_data,
-								enum rspamd_symbol_type type,
+								int type,
 								gint parent)
 {
 	auto *real_cache = C_API_SYMCACHE(cache);
@@ -687,7 +687,7 @@ void rspamd_symcache_composites_foreach(struct rspamd_task *task,
 gboolean
 rspamd_symcache_process_symbols(struct rspamd_task *task,
 								struct rspamd_symcache *cache,
-								gint stage)
+								guint stage)
 {
 	auto *real_cache = C_API_SYMCACHE(cache);
 
