@@ -1,3 +1,19 @@
+/*
+ * Copyright 2023 Vsevolod Stakhov
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 #ifndef UPSTREAM_H
 #define UPSTREAM_H
 
@@ -10,6 +26,9 @@
 extern "C" {
 #endif
 
+/* Forward declaration */
+struct ev_loop;
+
 enum rspamd_upstream_rotation {
 	RSPAMD_UPSTREAM_RANDOM = 0,
 	RSPAMD_UPSTREAM_HASHED,
