@@ -1,5 +1,5 @@
 /*
- * Copyright 2023 Vsevolod Stakhov
+ * Copyright 2024 Vsevolod Stakhov
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -533,12 +533,16 @@ void rspamd_signals_init(struct sigaction *signals, void (*sig_handler)(gint))
 static gchar *title_buffer = NULL;
 static size_t title_buffer_size = 0;
 static gchar *title_progname, *title_progname_full;
-#endif
+gchar **old_environ = NULL;
 
-#ifdef LINUX
 static void
 rspamd_title_dtor(gpointer d)
 {
+	/* Restore old environment */
+	if (old_environ != NULL) {
+		environ = old_environ;
+	}
+
 	gchar **env = (gchar **) d;
 	guint i;
 
@@ -548,12 +552,14 @@ rspamd_title_dtor(gpointer d)
 
 	g_free(env);
 }
-#endif
+#endif /* ifdef LINUX */
 
-gint init_title(rspamd_mempool_t *pool,
-				gint argc, gchar *argv[], gchar *envp[])
+#endif /* ifndef HAVE_SETPROCTITLE */
+
+gint rspamd_init_title(rspamd_mempool_t *pool,
+					   gint argc, gchar *argv[], gchar *envp[])
 {
-#ifdef LINUX
+#if defined(LINUX) && !defined(HAVE_SETPROCTITLE)
 	gchar *begin_of_buffer = 0, *end_of_buffer = 0;
 	gint i;
 
@@ -603,19 +609,33 @@ gint init_title(rspamd_mempool_t *pool,
 		program_invocation_short_name = title_progname;
 	}
 
+	old_environ = environ;
 	environ = new_environ;
 	title_buffer = begin_of_buffer;
 	title_buffer_size = end_of_buffer - begin_of_buffer;
 
 	rspamd_mempool_add_destructor(pool,
-								  rspamd_title_dtor, new_environ);
+								  rspamd_title_dtor,
+								  new_environ);
 #endif
 
 	return 0;
 }
 
-gint setproctitle(const gchar *fmt, ...)
+gint rspamd_setproctitle(const gchar *fmt, ...)
 {
+#ifdef HAVE_SETPROCTITLE
+	if (fmt) {
+		static char titlebuf[4096];
+		va_list ap;
+
+		va_start(ap, fmt);
+		rspamd_vsnprintf(titlebuf, sizeof(titlebuf), fmt, ap);
+		va_end(ap);
+
+		setproctitle("%s", titlebuf);
+	}
+#else
 #if defined(LINUX)
 	if (!title_buffer || !title_buffer_size) {
 		errno = ENOMEM;
@@ -669,11 +689,12 @@ gint setproctitle(const gchar *fmt, ...)
 	g_set_prgname(dest->str);
 	g_string_free(dest, TRUE);
 
-#endif
+#endif /* defined(LINUX) */
+
+#endif /* HAVE_SETPROCTITLE */
 	return 0;
 }
 
-#endif
 
 #ifndef HAVE_PIDFILE
 static gint _rspamd_pidfile_remove(rspamd_pidfh_t *pfh, gint freeit);
@@ -1565,14 +1586,14 @@ rspamd_get_calendar_ticks(void)
 	return res;
 }
 
-void rspamd_random_hex(guchar *buf, guint64 len)
+void rspamd_random_hex(gchar *buf, guint64 len)
 {
 	static const gchar hexdigests[16] = "0123456789abcdef";
 	gint64 i;
 
 	g_assert(len > 0);
 
-	ottery_rand_bytes(buf, ceil(len / 2.0));
+	ottery_rand_bytes((void *) buf, ceil(len / 2.0));
 
 	for (i = (gint64) len - 1; i >= 0; i -= 2) {
 		buf[i] = hexdigests[buf[i / 2] & 0xf];
@@ -1733,7 +1754,7 @@ rspamd_fast_random_seed(void)
 }
 
 /* wyrand */
-static inline uint64_t
+inline uint64_t
 rspamd_random_uint64_fast_seed(uint64_t *seed)
 {
 	*seed += UINT64_C(0xa0761d6478bd642f);
