@@ -1,5 +1,5 @@
 /*
- * Copyright 2023 Vsevolod Stakhov
+ * Copyright 2024 Vsevolod Stakhov
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -126,16 +126,11 @@ void rspamd_signals_init(struct sigaction *sa, void (*sig_handler)(gint,
 void rspamd_signals_init(struct sigaction *sa, void (*sig_handler)(gint));
 #endif
 
-#ifndef HAVE_SETPROCTITLE
-
 /*
  * Process title utility functions
  */
-gint init_title(rspamd_mempool_t *pool, gint argc, gchar *argv[], gchar *envp[]);
-
-gint setproctitle(const gchar *fmt, ...);
-
-#endif
+gint rspamd_init_title(rspamd_mempool_t *pool, gint argc, gchar *argv[], gchar *envp[]);
+gint rspamd_setproctitle(const gchar *fmt, ...);
 
 #ifndef HAVE_PIDFILE
 /*
@@ -382,7 +377,7 @@ guint64 rspamd_hash_seed(void);
  * @param buf
  * @param len
  */
-void rspamd_random_hex(guchar *buf, guint64 len);
+void rspamd_random_hex(gchar *buf, guint64 len);
 
 /**
  * Returns
@@ -408,6 +403,7 @@ gdouble rspamd_random_double(void);
  */
 gdouble rspamd_random_double_fast(void);
 gdouble rspamd_random_double_fast_seed(guint64 *seed);
+uint64_t rspamd_random_uint64_fast_seed(uint64_t *seed);
 guint64 rspamd_random_uint64_fast(void);
 
 /**
