@@ -18,7 +18,7 @@
 
 #include "lua_common.h"
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 extern "C" {
 #endif
 
@@ -40,7 +40,7 @@ struct lua_tree_cb_data {
 	guint64 random_seed;
 };
 
-void lua_tree_url_callback (gpointer key, gpointer value, gpointer ud);
+void lua_tree_url_callback(gpointer key, gpointer value, gpointer ud);
 
 /**
  * Fills a cbdata table based on the parameter at position pos
@@ -49,22 +49,22 @@ void lua_tree_url_callback (gpointer key, gpointer value, gpointer ud);
  * @param cbd
  * @return
  */
-gboolean lua_url_cbdata_fill (lua_State *L, gint pos,
-							  struct lua_tree_cb_data *cbd,
-							  guint default_protocols,
-							  guint default_flags,
-							  gsize max_urls);
+gboolean lua_url_cbdata_fill(lua_State *L, gint pos,
+							 struct lua_tree_cb_data *cbd,
+							 guint default_protocols,
+							 guint default_flags,
+							 gsize max_urls);
 
-gboolean lua_url_cbdata_fill_exclude_include (lua_State *L, gint pos,
-							  struct lua_tree_cb_data *cbd,
-							  guint default_protocols,
-							  gsize max_urls);
+gboolean lua_url_cbdata_fill_exclude_include(lua_State *L, gint pos,
+											 struct lua_tree_cb_data *cbd,
+											 guint default_protocols,
+											 gsize max_urls);
 
 /**
  * Cleanup url cbdata
  * @param cbd
  */
-void lua_url_cbdata_dtor (struct lua_tree_cb_data *cbd);
+void lua_url_cbdata_dtor(struct lua_tree_cb_data *cbd);
 
 /**
  * Adjust probabilistic skip of the urls
@@ -75,12 +75,12 @@ void lua_url_cbdata_dtor (struct lua_tree_cb_data *cbd);
  * @param max_urls
  * @return
  */
-gsize lua_url_adjust_skip_prob (float timestamp,
-								guchar *digest,
-								struct lua_tree_cb_data *cb,
-								gsize sz);
+gsize lua_url_adjust_skip_prob(float timestamp,
+							   guchar digest[16],
+							   struct lua_tree_cb_data *cb,
+							   gsize sz);
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 }
 #endif
 
