@@ -1,5 +1,5 @@
 --[[
-Copyright (c) 2011-2015, Vsevolod Stakhov <vsevolod@highsecure.ru>
+Copyright (c) 2022, Vsevolod Stakhov <vsevolod@rspamd.com>
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -28,13 +28,16 @@ local lua_maps = require "lua_maps"
 --
 local N = 'phishing'
 local symbol = 'PHISHED_URL'
+local phishing_feed_exclusion_symbol = 'PHISHED_EXCLUDED'
 local generic_service_symbol = 'PHISHED_GENERIC_SERVICE'
 local openphish_symbol = 'PHISHED_OPENPHISH'
 local phishtank_symbol = 'PHISHED_PHISHTANK'
 local generic_service_name = 'generic service'
 local domains = nil
-local strict_domains = {}
-local exceptions_maps = {}
+local phishing_exceptions_maps = {}
+local anchor_exceptions_maps = {}
+local strict_domains_maps = {}
+local phishing_feed_exclusion_map = nil
 local generic_service_map = nil
 local openphish_map = 'https://www.openphish.com/feed.txt'
 local phishtank_suffix = 'phishtank.rspamd.com'
@@ -42,24 +45,45 @@ local phishtank_suffix = 'phishtank.rspamd.com'
 local openphish_premium = false
 -- Published via DNS
 local phishtank_enabled = false
+local phishing_feed_exclusion_hash
 local generic_service_hash
 local openphish_hash
+local phishing_feed_exclusion_data = {}
 local generic_service_data = {}
 local openphish_data = {}
 
-
 local opts = rspamd_config:get_all_opt(N)
 if not (opts and type(opts) == 'table') then
   rspamd_logger.infox(rspamd_config, 'Module is unconfigured')
   return
 end
 
+local function is_host_excluded(exclusion_map, host)
+  if exclusion_map and host then
+    local excluded = exclusion_map[host]
+    if excluded then
+      return true
+    end
+    return false
+  end
+end
+
 local function phishing_cb(task)
-  local function check_phishing_map(map, url, phish_symbol)
+  local function check_phishing_map(table)
+    local phishing_data = {}
+    for k,v in pairs(table) do
+      phishing_data[k] = v
+    end
+    local url = phishing_data.url
     local host = url:get_host()
 
+    if is_host_excluded(phishing_data.exclusion_map, host) then
+      task:insert_result(phishing_data.excl_symbol, 1.0, host)
+      return
+    end
+
     if host then
-      local elt = map[host]
+      local elt = phishing_data.map[host]
       local found_path = false
       local found_query = false
       local data = nil
@@ -69,7 +93,7 @@ local function phishing_cb(task)
         local query = url:get_query()
 
         if path then
-          for _,d in ipairs(elt) do
+          for _, d in ipairs(elt) do
             if d['path'] == path then
               found_path = true
               data = d['data']
@@ -82,7 +106,7 @@ local function phishing_cb(task)
             end
           end
         else
-          for _,d in ipairs(elt) do
+          for _, d in ipairs(elt) do
             if not d['path'] then
               found_path = true
             end
@@ -112,33 +136,47 @@ local function phishing_cb(task)
 
           if found_query then
             -- Query + path match
-            task:insert_result(phish_symbol, 1.0, args)
+            task:insert_result(phishing_data.phish_symbol, 1.0, args)
           else
             -- Host + path match
             if path then
-              task:insert_result(phish_symbol, 0.3, args)
+              task:insert_result(phishing_data.phish_symbol, 0.3, args)
             end
             -- No path, no symbol
           end
         else
           if url:is_phished() then
             -- Only host matches
-            task:insert_result(phish_symbol, 0.1, host)
+            task:insert_result(phishing_data.phish_symbol, 0.1, host)
           end
         end
       end
     end
   end
 
-  local function check_phishing_dns(dns_suffix, url, phish_symbol)
+  local function check_phishing_dns(table)
+    local phishing_data = {}
+    for k,v in pairs(table) do
+      phishing_data[k] = v
+    end
+    local url = phishing_data.url
+    local host = url:get_host()
+
+    if is_host_excluded(phishing_data.exclusion_map, host) then
+      task:insert_result(phishing_data.excl_symbol, 1.0, host)
+      return
+    end
+
     local function compose_dns_query(elts)
       local cr = require "rspamd_cryptobox_hash"
       local h = cr.create()
-      for _,elt in ipairs(elts) do h:update(elt) end
-      return string.format("%s.%s", h:base32():sub(1, 32), dns_suffix)
+      for _, elt in ipairs(elts) do
+        h:update(elt)
+      end
+      return string.format("%s.%s", h:base32():sub(1, 32), phishing_data.dns_suffix)
     end
+
     local r = task:get_resolver()
-    local host = url:get_host()
     local path = url:get_path()
     local query = url:get_query()
 
@@ -146,36 +184,35 @@ local function phishing_cb(task)
       local function host_host_path_cb(_, _, results, err)
         if not err and results then
           if not query then
-            task:insert_result(phish_symbol, 1.0, results)
+            task:insert_result(phishing_data.phish_symbol, 1.0, results)
           else
-            task:insert_result(phish_symbol, 0.3, results)
+            task:insert_result(phishing_data.phish_symbol, 0.3, results)
           end
         end
       end
 
-      local to_resolve_hp = compose_dns_query({host, path})
+      local to_resolve_hp = compose_dns_query({ host, path })
       rspamd_logger.debugm(N, task, 'try to resolve {%s, %s} -> %s',
           host, path, to_resolve_hp)
       r:resolve_txt({
         task = task,
         name = to_resolve_hp,
-        callback = host_host_path_cb})
-
+        callback = host_host_path_cb })
 
       if query then
         local function host_host_path_query_cb(_, _, results, err)
           if not err and results then
-            task:insert_result(phish_symbol, 1.0, results)
+            task:insert_result(phishing_data.phish_symbol, 1.0, results)
           end
         end
 
-        local to_resolve_hpq = compose_dns_query({host, path, query})
+        local to_resolve_hpq = compose_dns_query({ host, path, query })
         rspamd_logger.debugm(N, task, 'try to resolve {%s, %s, %s} -> %s',
             host, path, query, to_resolve_hpq)
         r:resolve_txt({
           task = task,
           name = to_resolve_hpq,
-          callback = host_host_path_query_cb})
+          callback = host_host_path_query_cb })
       end
 
     end
@@ -192,19 +229,30 @@ local function phishing_cb(task)
   end
 
   local urls = task:get_urls() or {}
-  for _,url_iter in ipairs(urls) do
-    local function do_loop_iter() -- to emulate continue
+  for _, url_iter in ipairs(urls) do
+    local function do_loop_iter()
+      -- to emulate continue
       local url = url_iter
+      local phishing_data = {}
+      phishing_data.url = url
+      phishing_data.exclusion_map = phishing_feed_exclusion_data
+      phishing_data.excl_symbol = phishing_feed_exclusion_symbol
       if generic_service_hash then
-        check_phishing_map(generic_service_data, url, generic_service_symbol)
+        phishing_data.map = generic_service_data
+        phishing_data.phish_symbol = generic_service_symbol
+        check_phishing_map(phishing_data)
       end
 
       if openphish_hash then
-        check_phishing_map(openphish_data, url, openphish_symbol)
+        phishing_data.map = openphish_data
+        phishing_data.phish_symbol = openphish_symbol
+        check_phishing_map(phishing_data)
       end
 
       if phishtank_enabled then
-        check_phishing_dns(phishtank_suffix, url, phishtank_symbol)
+        phishing_data.dns_suffix = phishtank_suffix
+        phishing_data.phish_symbol = phishtank_symbol
+        check_phishing_dns(phishing_data)
       end
 
       if url:is_phished() then
@@ -224,7 +272,6 @@ local function phishing_cb(task)
           purl = url:get_phished()
         end
 
-
         if not purl then
           return
         end
@@ -238,15 +285,15 @@ local function phishing_cb(task)
 
         if dmarc_dom and tld == dmarc_dom then
           lua_util.debugm(N, 'exclude phishing from %s -> %s by dmarc domain', tld,
-                  ptld)
+              ptld)
           return
         end
 
         -- Now we can safely remove the last dot component if it is the same
-        local b,_ = string.find(tld, '%.[^%.]+$')
-        local b1,_ = string.find(ptld, '%.[^%.]+$')
+        local b, _ = string.find(tld, '%.[^%.]+$')
+        local b1, _ = string.find(ptld, '%.[^%.]+$')
 
-        local stripped_tld,stripped_ptld = tld, ptld
+        local stripped_tld, stripped_ptld = tld, ptld
         if b1 and b then
           if string.sub(tld, b) == string.sub(ptld, b1) then
             stripped_ptld = string.gsub(ptld, '%.[^%.]+$', '')
@@ -259,7 +306,7 @@ local function phishing_cb(task)
         end
 
         local weight = 1.0
-        local spoofed,why = util.is_utf_spoofed(tld, ptld)
+        local spoofed, why = util.is_utf_spoofed(tld, ptld)
         if spoofed then
           lua_util.debugm(N, task, "confusable: %1 -> %2: %3", tld, ptld, why)
           weight = 1.0
@@ -272,15 +319,19 @@ local function phishing_cb(task)
             weight = util.tanh(3 * (1 - dist + 0.1))
           elseif dist > 1 then
             -- We also check if two labels are in the same ascii/non-ascii representation
-            local a1, a2 = false,false
+            local a1, a2 = false, false
 
-            if string.match(tld, '^[\001-\127]*$') then a1 = true end
-            if string.match(ptld, '^[\001-\127]*$') then a2 = true end
+            if string.match(tld, '^[\001-\127]*$') then
+              a1 = true
+            end
+            if string.match(ptld, '^[\001-\127]*$') then
+              a2 = true
+            end
 
             if a1 ~= a2 then
               weight = 1
               lua_util.debugm(N, task, "confusable: %1 -> %2: different characters",
-                      tld, ptld, why)
+                  tld, ptld, why)
             else
               -- We have totally different strings in tld, so penalize it somehow
               weight = 0.5
@@ -291,30 +342,35 @@ local function phishing_cb(task)
         end
 
         local function is_url_in_map(map, furl)
-          for _,dn in ipairs({furl:get_tld(), furl:get_host()}) do
+          for _, dn in ipairs({ furl:get_tld(), furl:get_host() }) do
             if map:get_key(dn) then
-              return true,dn
+              return true, dn
             end
           end
 
           return false
         end
         local function found_in_map(map, furl, sweight)
-          if not furl then furl = url end
-          if not sweight then sweight = weight end
+          if not furl then
+            furl = url
+          end
+          if not sweight then
+            sweight = weight
+          end
           if #map > 0 then
-            for _,rule in ipairs(map) do
-              local found,dn = is_url_in_map(rule.map, furl)
+            for _, rule in ipairs(map) do
+              local found, dn = is_url_in_map(rule.map, furl)
               if found then
-                task:insert_result(rule.symbol, sweight, ptld .. '->' .. dn)
+                task:insert_result(rule.symbol, sweight, string.format("%s->%s:%s", ptld, tld, dn))
                 return true
               end
             end
           end
         end
 
-        if not found_in_map(exceptions_maps) then
-          if not found_in_map(strict_domains, purl, 1.0) then
+        found_in_map(strict_domains_maps, purl, 1.0)
+        if not found_in_map(anchor_exceptions_maps) then
+          if not found_in_map(phishing_exceptions_maps, purl, 1.0) then
             if domains then
               if is_url_in_map(domains, purl) then
                 task:insert_result(symbol, weight, ptld .. '->' .. tld)
@@ -340,13 +396,12 @@ local function phishing_map(mapname, phishmap, id)
       rspamd_logger.errx(rspamd_config, 'invalid exception table')
     end
 
-
-    for sym,map_data in pairs(xd) do
-      local rmap = lua_maps.map_add_from_ucl (map_data, 'set',
-              'Phishing ' .. mapname .. ' map')
+    for sym, map_data in pairs(xd) do
+      local rmap = lua_maps.map_add_from_ucl(map_data, 'set',
+          'Phishing ' .. mapname .. ' map')
       if rmap then
         rspamd_config:register_virtual_symbol(sym, 1, id)
-        local rule = {symbol = sym, map = rmap}
+        local rule = { symbol = sym, map = rmap }
         table.insert(phishmap, rule)
       else
         rspamd_logger.infox(rspamd_config, 'cannot add map for symbol: %s', sym)
@@ -358,8 +413,8 @@ end
 local function rspamd_str_split_fun(s, sep, func)
   local lpeg = require "lpeg"
   sep = lpeg.P(sep)
-  local elem = lpeg.P((1 - sep)^0 / func)
-  local p = lpeg.P(elem * (sep * elem)^0)
+  local elem = lpeg.P((1 - sep) ^ 0 / func)
+  local p = lpeg.P(elem * (sep * elem) ^ 0)
   return p:match(s)
 end
 
@@ -380,7 +435,7 @@ local function insert_url_from_string(pool, tbl, str, data)
       if tbl[host] then
         table.insert(tbl[host], elt)
       else
-        tbl[host] = {elt}
+        tbl[host] = { elt }
       end
 
       return true
@@ -390,6 +445,26 @@ local function insert_url_from_string(pool, tbl, str, data)
   return false
 end
 
+local function phishing_feed_exclusion_plain_cb(string)
+  local nelts = 0
+  local new_data = {}
+  local rspamd_mempool = require "rspamd_mempool"
+  local pool = rspamd_mempool.create()
+
+  local function phishing_feed_exclusion_elt_parser(cap)
+    if insert_url_from_string(pool, new_data, cap, nil) then
+      nelts = nelts + 1
+    end
+  end
+
+  rspamd_str_split_fun(string, '\n', phishing_feed_exclusion_elt_parser)
+
+  phishing_feed_exclusion_data = new_data
+  rspamd_logger.infox(phishing_feed_exclusion_hash, "parsed %s elements from phishing feed exclusions",
+      nelts)
+  pool:destroy()
+end
+
 local function generic_service_plain_cb(string)
   local nelts = 0
   local new_data = {}
@@ -406,7 +481,7 @@ local function generic_service_plain_cb(string)
 
   generic_service_data = new_data
   rspamd_logger.infox(generic_service_hash, "parsed %s elements from %s feed",
-    nelts, generic_service_name)
+      nelts, generic_service_name)
   pool:destroy()
 end
 
@@ -422,7 +497,7 @@ local function openphish_json_cb(string)
   local function openphish_elt_parser(cap)
     if valid then
       local parser = ucl.parser()
-      local res,err = parser:parse_string(cap)
+      local res, err = parser:parse_string(cap)
       if not res then
         valid = false
         rspamd_logger.warnx(openphish_hash, 'cannot parse openphish map: ' .. err)
@@ -443,7 +518,7 @@ local function openphish_json_cb(string)
   if valid then
     openphish_data = new_json_map
     rspamd_logger.infox(openphish_hash, "parsed %s elements from openphish feed",
-      nelts)
+        nelts)
   end
 
   pool:destroy()
@@ -465,7 +540,7 @@ local function openphish_plain_cb(s)
 
   openphish_data = new_data
   rspamd_logger.infox(openphish_hash, "parsed %s elements from openphish feed",
-    nelts)
+      nelts)
   pool:destroy()
 end
 
@@ -482,6 +557,22 @@ if opts then
     -- To exclude from domains for dmarc verified messages
     rspamd_config:register_dependency(symbol, 'DMARC_CHECK')
 
+    if opts['phishing_feed_exclusion_symbol'] then
+      phishing_feed_exclusion_symbol = opts['phishing_feed_exclusion_symbol']
+    end
+    if opts['phishing_feed_exclusion_map'] then
+      phishing_feed_exclusion_map = opts['phishing_feed_exclusion_map']
+    end
+
+    if opts['phishing_feed_exclusion_enabled'] then
+      phishing_feed_exclusion_hash = rspamd_config:add_map({
+        type = 'callback',
+        url = phishing_feed_exclusion_map,
+        callback = phishing_feed_exclusion_plain_cb,
+        description = 'Phishing feed exclusions'
+      })
+    end
+
     if opts['generic_service_symbol'] then
       generic_service_symbol = opts['generic_service_symbol']
     end
@@ -497,11 +588,11 @@ if opts then
 
     if opts['generic_service_enabled'] then
       generic_service_hash = rspamd_config:add_map({
-          type = 'callback',
-          url = generic_service_map,
-          callback = generic_service_plain_cb,
-          description = 'Generic feed'
-        })
+        type = 'callback',
+        url = generic_service_map,
+        callback = generic_service_plain_cb,
+        description = 'Generic feed'
+      })
     end
 
     if opts['openphish_map'] then
@@ -526,12 +617,12 @@ if opts then
         })
       else
         openphish_hash = rspamd_config:add_map({
-            type = 'callback',
-            url = openphish_map,
-            callback = openphish_json_cb,
-            opaque_data = true,
-            description = 'Open phishing premium feed map (see https://www.openphish.com for details)'
-          })
+          type = 'callback',
+          url = openphish_map,
+          callback = openphish_json_cb,
+          opaque_data = true,
+          description = 'Open phishing premium feed map (see https://www.openphish.com for details)'
+        })
       end
     end
 
@@ -548,6 +639,12 @@ if opts then
       name = generic_service_symbol,
     })
 
+    rspamd_config:register_symbol({
+      type = 'virtual',
+      parent = id,
+      name = phishing_feed_exclusion_symbol,
+    })
+
     rspamd_config:register_symbol({
       type = 'virtual',
       parent = id,
@@ -562,8 +659,9 @@ if opts then
   end
   if opts['domains'] and type(opts['domains']) == 'string' then
     domains = lua_maps.map_add_from_ucl(opts['domains'], 'set',
-            'Phishing domains')
+        'Phishing domains')
   end
-  phishing_map('strict_domains', strict_domains, id)
-  phishing_map('exceptions', exceptions_maps, id)
+  phishing_map('phishing_exceptions', phishing_exceptions_maps, id)
+  phishing_map('exceptions', anchor_exceptions_maps, id)
+  phishing_map('strict_domains', strict_domains_maps, id)
 end
