@@ -151,9 +151,7 @@ local function gen_check_rcvd_conditions(rbl, received_total)
     end
     if ((rh.real_ip:get_version() == 6 and rbl.ipv6) or
         (rh.real_ip:get_version() == 4 and rbl.ipv4)) and
-        ((rbl.exclude_private_ips and not rh.real_ip:is_local()) or
-            not rbl.exclude_private_ips) and ((rbl.exclude_local_ips and
-        not is_excluded_ip(rh.real_ip)) or not rbl.exclude_local_ips) then
+        ((rbl.exclude_local and not rh.real_ip:is_local() or is_excluded_ip(rh.real_ip)) or not rbl.exclude_local) then
       return true
     else
       return false
@@ -845,7 +843,7 @@ local function gen_rbl_callback(rule)
     description[#description + 1] = 'user'
   end
 
-  if rule.exclude_local or rule.exclude_private_ips then
+  if rule.exclude_local then
     pipeline[#pipeline + 1] = check_local
     description[#description + 1] = 'local'
   end
@@ -1119,11 +1117,11 @@ local function add_rbl(key, rbl, global_opts)
     end
   end
 
-  if not rbl.whitelist and global_opts.url_whitelist and
+  if not rbl.whitelist and not rbl.ignore_url_whitelist and (global_opts.url_whitelist or rbl.url_whitelist) and
       (rbl.urls or rbl.emails or rbl.dkim or rbl.replyto) and
       not (rbl.from or rbl.received) then
     local def_type = 'set'
-    rbl.whitelist = lua_maps.map_add_from_ucl(global_opts.url_whitelist, def_type,
+    rbl.whitelist = lua_maps.map_add_from_ucl(rbl.url_whitelist or global_opts.url_whitelist, def_type,
         'RBL url whitelist for ' .. rbl.symbol)
     rspamd_logger.infox(rspamd_config, 'added URL whitelist for RBL %s',
         rbl.symbol)
@@ -1344,7 +1342,7 @@ for key, rbl in pairs(opts.rbls) do
       rspamd_logger.errx(rspamd_config, 'invalid config for %s: %s, RBL is DISABLED',
           key, err)
     else
-      res = rbl_common.convert_checks(res)
+      res = rbl_common.convert_checks(res, rbl.symbol or key:upper())
       -- Aliases
       if res.return_codes then
         res.returncodes = res.return_codes
