@@ -1,20 +1,23 @@
 local logger = require "rspamd_logger"
 
-rspamd_config:register_symbol({
-  name = 'SPAM_SYMBOL',
-  score = 5.0,
-  callback = function()
-    return true, 'Fires always'
-  end
-})
+for i = 1,14 do
+  rspamd_config:register_symbol({
+    name = 'SPAM_SYMBOL'..tostring(i),
+    score = 5.0,
+    callback = function()
+      return true, 'Fires always'
+    end
+  })
+  rspamd_config:register_symbol({
+    name = 'HAM_SYMBOL'..tostring(i),
+    score = -3.0,
+    callback = function()
+      return true, 'Fires always'
+    end
+  })
+end
+
 
-rspamd_config:register_symbol({
-  name = 'HAM_SYMBOL',
-  score = -3.0,
-  callback = function()
-    return true, 'Fires always'
-  end
-})
 
 rspamd_config:register_symbol({
   name = 'NEUTRAL_SYMBOL',
@@ -55,7 +58,7 @@ rspamd_config.SAVE_NN_ROW_IDEMPOTENT = {
   end,
   type = 'idempotent',
   flags = 'explicit_disable',
-  priority = 10,
+  priority = 100,
 }
 
 dofile(rspamd_env.INSTALLROOT .. "/share/rspamd/rules/controller/init.lua")
